@@ -6,9 +6,11 @@ from sklearn.metrics import (accuracy_score, f1_score, log_loss, mean_absolute_e
                              mean_squared_error, mean_squared_log_error, precision_score, r2_score, roc_auc_score,
                              silhouette_score)
 
-from fedot.core.chains.chain import Chain
 from fedot.core.data.data import InputData, OutputData
+from fedot.core.repository.dataset_types import DataTypesEnum
+from fedot.core.pipelines.pipeline import Pipeline
 from fedot.core.repository.tasks import TaskTypesEnum
+from fedot.core.pipelines.ts_wrappers import in_sample_ts_forecast
 
 
 def from_maximised_metric(metric_func):
@@ -24,7 +26,9 @@ class Metric:
 
     @classmethod
     @abstractmethod
-    def get_value(cls, chain: Chain, reference_data: InputData) -> float:
+    def get_value(cls, pipeline: Pipeline, reference_data: InputData,
+                  validation_blocks: int) -> float:
+        """ Get metrics values based on pipeline and InputData for validation """
         raise NotImplementedError()
 
     @staticmethod
@@ -39,32 +43,89 @@ class QualityMetric:
     default_value = 0
 
     @classmethod
-    def get_value(cls, chain: Chain, reference_data: InputData) -> float:
+    def get_value(cls, pipeline: Pipeline, reference_data: InputData,
+                  validation_blocks: int = None) -> float:
         metric = cls.default_value
         try:
-            results = chain.predict(reference_data, output_mode=cls.output_mode)
-
-            if reference_data.task.task_type == TaskTypesEnum.ts_forecasting:
-                # Convert prediction into one-dimensional array
-                forecast_values = np.ravel(np.array(results.predict))
-                results.predict = forecast_values
-                metric = cls.metric(reference_data, results)
+            if validation_blocks is None:
+                # Time series or regression classical hold-out validation
+                results, reference_data = cls._simple_prediction(pipeline, reference_data)
             else:
-                metric = cls.metric(reference_data, results)
+                # Perform time series in-sample validation
+                reference_data, results = cls._in_sample_prediction(pipeline, reference_data, validation_blocks)
+            metric = cls.metric(reference_data, results)
         except Exception as ex:
             print(f'Metric evaluation error: {ex}')
         return metric
 
     @classmethod
-    def get_value_with_penalty(cls, chain: Chain, reference_data: InputData) -> float:
-        quality_metric = cls.get_value(chain, reference_data)
-        structural_metric = StructuralComplexity.get_value(chain)
+    def _simple_prediction(cls, pipeline: Pipeline, reference_data: InputData):
+        """ Method prepares data for metric evaluation and perform simple validation """
+        results = pipeline.predict(reference_data, output_mode=cls.output_mode)
+
+        # Define conditions for target and predictions transforming
+        is_regression = reference_data.task.task_type == TaskTypesEnum.regression
+        is_multi_target = len(np.array(results.predict).shape) > 1
+        is_multi_target_regression = is_regression and is_multi_target
+
+        # Time series forecasting
+        is_ts_forecasting = reference_data.task.task_type == TaskTypesEnum.ts_forecasting
+        if is_ts_forecasting or is_multi_target_regression:
+            results, reference_data = cls.flatten_convert(results, reference_data)
+
+        return results, reference_data
+
+    @staticmethod
+    def flatten_convert(results, reference_data):
+        """ Transform target and predictions by converting them into
+        one-dimensional array
+
+        :param results: output from pipeline
+        :param reference_data: actual data for validation
+        """
+        # Predictions convert into uni-variate array
+        forecast_values = np.ravel(np.array(results.predict))
+        results.predict = forecast_values
+        # Target convert into uni-variate array
+        target_values = np.ravel(np.array(reference_data.target))
+        reference_data.target = target_values
+
+        return results, reference_data
+
+    @classmethod
+    def get_value_with_penalty(cls, pipeline: Pipeline, reference_data: InputData,
+                               validation_blocks: int = None) -> float:
+        quality_metric = cls.get_value(pipeline, reference_data)
+        structural_metric = StructuralComplexity.get_value(pipeline)
 
         penalty = abs(structural_metric * quality_metric * cls.max_penalty_part)
         metric_with_penalty = (quality_metric +
                                min(penalty, abs(quality_metric * cls.max_penalty_part)))
         return metric_with_penalty
 
+    @staticmethod
+    def _in_sample_prediction(pipeline, data, validation_blocks):
+        """ Performs in-sample pipeline validation for time series prediction """
+
+        # Get number of validation blocks per each fold
+        horizon = data.task.task_params.forecast_length * validation_blocks
+
+        predicted_values = in_sample_ts_forecast(pipeline=pipeline,
+                                                 input_data=data,
+                                                 horizon=horizon)
+
+        # Clip actual data by the forecast horizon length
+        actual_values = data.target[-horizon:]
+
+        # Wrap target and prediction arrays into OutputData and InputData
+        results = OutputData(idx=np.arange(0, len(predicted_values)), features=predicted_values,
+                             predict=predicted_values, task=data.task, target=predicted_values,
+                             data_type=DataTypesEnum.ts)
+        reference_data = InputData(idx=np.arange(0, len(actual_values)), features=actual_values,
+                                   task=data.task, target=actual_values, data_type=DataTypesEnum.ts)
+
+        return reference_data, results
+
     @staticmethod
     @abstractmethod
     def metric(reference: InputData, predicted: OutputData) -> float:
@@ -196,19 +257,19 @@ class Silhouette(QualityMetric):
 
 class StructuralComplexity(Metric):
     @classmethod
-    def get_value(cls, chain: Chain, **args) -> float:
+    def get_value(cls, pipeline: Pipeline, **args) -> float:
         norm_constant = 30
-        return (chain.depth ** 2 + chain.length) / norm_constant
+        return (pipeline.depth ** 2 + pipeline.length) / norm_constant
 
 
 class NodeNum(Metric):
     @classmethod
-    def get_value(cls, chain: Chain, **args) -> float:
+    def get_value(cls, pipeline: Pipeline, **args) -> float:
         norm_constant = 10
-        return chain.length / norm_constant
+        return pipeline.length / norm_constant
 
 
 class ComputationTime(Metric):
     @classmethod
-    def get_value(cls, chain: Chain, **args) -> float:
-        return chain.computation_time
+    def get_value(cls, pipeline: Pipeline, **args) -> float:
+        return pipeline.computation_time
