@@ -5,20 +5,20 @@ from typing import (Any, Callable, List, Optional)
 
 from numpy import random
 
-from fedot.core.chains.chain import Chain, Node
-from fedot.core.chains.node import PrimaryNode, SecondaryNode
 from fedot.core.composer.composer import ComposerRequirements
 from fedot.core.data.data import InputData
+from fedot.core.pipelines.node import PrimaryNode, SecondaryNode
+from fedot.core.pipelines.pipeline import Node, Pipeline
 
 
 class RandomSearchComposer:
     def __init__(self, iter_num: int = 10):
         self.__iter_num = iter_num
 
-    def compose_chain(self, data: InputData,
-                      initial_chain: Optional[Chain],
-                      composer_requirements: ComposerRequirements,
-                      metrics: Optional[Callable]) -> Chain:
+    def compose_pipeline(self, data: InputData,
+                         initial_pipeline: Optional[Pipeline],
+                         composer_requirements: ComposerRequirements,
+                         metrics: Optional[Callable]) -> Pipeline:
         # TODO: fix this later?
         train_data = data
         test_data = data
@@ -32,22 +32,22 @@ class RandomSearchComposer:
                                                      composer_requirements.primary,
                                                      composer_requirements.secondary)
 
-        best_chain = Chain()
-        [best_chain.add_node(nodes) for nodes in best_nodes_set]
+        best_pipeline = Pipeline()
+        [best_pipeline.add_node(nodes) for nodes in best_nodes_set]
 
-        return best_chain
+        return best_pipeline
 
 
-def nodes_to_chain(nodes: List[Node]) -> Chain:
-    chain = Chain()
-    [chain.add_node(nodes) for nodes in nodes]
-    return chain
+def nodes_to_pipeline(nodes: List[Node]) -> Pipeline:
+    pipeline = Pipeline()
+    [pipeline.add_node(nodes) for nodes in nodes]
+    return pipeline
 
 
 def metric_for_nodes(metric_function, nodes: List[Node], train_data: InputData, test_data: InputData) -> float:
-    chain = nodes_to_chain(nodes)
-    chain.fit(input_data=train_data)
-    return metric_function(chain, test_data)
+    pipeline = nodes_to_pipeline(nodes)
+    pipeline.fit(input_data=train_data)
+    return metric_function(pipeline, test_data)
 
 
 class RandomSearchOptimiser:
@@ -72,7 +72,7 @@ class RandomSearchOptimiser:
             if new_metric_value < best_metric_value:
                 best_metric_value = new_metric_value
                 best_set = new_nodeset
-                print(f'Better chain found: metric {best_metric_value}')
+                print(f'Better pipeline found: metric {best_metric_value}')
 
         return best_set, history
 
