@@ -1,60 +1,60 @@
-from uuid import uuid4
 from typing import Callable
 
-from fedot.core.chains.chain import Chain
 from fedot.core.data.data import InputData
 from fedot.core.operations.operation import Operation
+from fedot.core.pipelines.pipeline import Pipeline
 from fedot.core.repository.operation_types_repository import OperationMetaInfo, \
-    atomized_model_meta_tags, atomized_model_type
-from fedot.core.utils import make_chain_generator
+    atomized_model_type
+from fedot.core.utils import make_pipeline_generator
 
 
 class AtomizedModel(Operation):
     """ Class which replace Operation class for AtomizedModel object """
-    def __init__(self, chain: 'Chain'):
-        if not chain.root_node:
-            raise ValueError(f'AtomizedModel could not create instance of empty Chain.')
+
+    def __init__(self, pipeline: 'Pipeline'):
+        if not pipeline.root_node:
+            raise ValueError(f'AtomizedModel could not create instance of empty Pipeline.')
 
         super().__init__(operation_type=atomized_model_type())
-        self.chain = chain
-        self.unique_id = uuid4()
+        self.pipeline = pipeline
+        self.unique_id = self.pipeline.root_node.descriptive_id
 
-    def fit(self, data: InputData, is_fit_chain_stage: bool = True,
+    def fit(self, data: InputData, is_fit_pipeline_stage: bool = True,
             use_cache: bool = True):
 
-        predicted_train = self.chain.fit(input_data=data)
-        fitted_atomized_operation_head = self.chain.root_node
+        predicted_train = self.pipeline.fit(input_data=data)
+        fitted_atomized_operation = self.pipeline
 
-        return fitted_atomized_operation_head, predicted_train
+        return fitted_atomized_operation, predicted_train
 
     def predict(self, fitted_operation, data: InputData,
-                is_fit_chain_stage: bool = False, output_mode: str = 'default'):
-        prediction = self.chain.predict(input_data=data, output_mode=output_mode)
+                is_fit_pipeline_stage: bool = False, output_mode: str = 'default'):
+        prediction = fitted_operation.predict(input_data=data, output_mode=output_mode)
 
         return prediction
 
     def fine_tune(self, loss_function: Callable,
                   loss_params: Callable = None,
                   input_data: InputData = None, iterations: int = 50,
-                  max_lead_time: int = 5):
+                  timeout: int = 5):
         """ Method for tuning hyperparameters """
-        tuned_chain = self.chain.fine_tune_all_nodes(loss_function=loss_function,
-                                                     loss_params=loss_params,
-                                                     input_data=input_data,
-                                                     iterations=iterations,
-                                                     max_lead_time=max_lead_time)
-        tuned_atomized_model = AtomizedModel(tuned_chain)
+        tuned_pipeline = self.pipeline.fine_tune_all_nodes(loss_function=loss_function,
+                                                           loss_params=loss_params,
+                                                           input_data=input_data,
+                                                           iterations=iterations,
+                                                           timeout=timeout)
+        tuned_atomized_model = AtomizedModel(tuned_pipeline)
         return tuned_atomized_model
 
     @property
     def metadata(self) -> OperationMetaInfo:
-        generator = make_chain_generator(self.chain)
+        generator = make_pipeline_generator(self.pipeline)
         tags = set()
 
         for node in generator:
             tags.update(node.operation_tags)
 
-        root_node = self.chain.root_node
+        root_node = self.pipeline.root_node
         supported_strategies = None
         allowed_positions = ['any']
         tags = list(tags)
@@ -70,12 +70,12 @@ class AtomizedModel(Operation):
     @property
     def description(self):
         operation_type = self.operation_type
-        operation_length = self.chain.length
-        operation_depth = self.chain.depth
+        operation_length = self.pipeline.length
+        operation_depth = self.pipeline.depth
         operation_id = self.unique_id
         operation_types = {}
 
-        for node in self.chain.nodes:
+        for node in self.pipeline.nodes:
             if node.operation.operation_type in operation_types:
                 operation_types[node.operation.operation_type] += 1
             else:
